<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="lt">
<context>
    <name>ChainsProxyPage</name>
    <message>
        <source>Application Proxy</source>
        <translation>Programos įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Įgaliotojo serverio tipas</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Prievadas</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Nebūtina</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Check &quot;Use a proxy&quot; in application context menu in Launcher after configured</source>
        <translation>Sukonfigūravę, leistuke, programos kontekstiniame meniu ieškokite &quot;Naudoti įgaliotąjį serverį&quot;</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neteisingas IP adresas</translation>
    </message>
    <message>
        <source>Invalid port</source>
        <translation>Neteisingas prievadas</translation>
    </message>
</context>
<context>
    <name>ConnectionEditPage</name>
    <message>
        <source>Disconnect</source>
        <comment>button</comment>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>Ištrinti</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Jungiamasi</translation>
    </message>
    <message>
        <source>Disconnect</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Are you sure you want to delete this configuration?</source>
        <translation>Ar tikrai norite ištrinti šią konfigūraciją?</translation>
    </message>
    <message>
        <source>Wired Connection %1</source>
        <translation>Laidinis ryšys %1</translation>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Prieigos taškas</translation>
    </message>
    <message>
        <source>Wireless Connection %1</source>
        <translation>Belaidis ryšys %1</translation>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation>PPPoE ryšys %1</translation>
    </message>
</context>
<context>
    <name>ConnectionVpnEditPage</name>
    <message>
        <source>New VPN</source>
        <translation>Naujas VPN</translation>
    </message>
    <message>
        <source>VPN Type</source>
        <translation>VPN tipas</translation>
    </message>
    <message>
        <source>L2TP</source>
        <translation>L2TP</translation>
    </message>
    <message>
        <source>PPTP</source>
        <translation>PPTP</translation>
    </message>
    <message>
        <source>OpenVPN</source>
        <translation>OpenVPN</translation>
    </message>
    <message>
        <source>OpenConnect</source>
        <translation>OpenConnect</translation>
    </message>
    <message>
        <source>StrongSwan</source>
        <translation>StrongSwan</translation>
    </message>
    <message>
        <source>VPNC</source>
        <translation>VPNC</translation>
    </message>
    <message>
        <source>Export</source>
        <comment>button</comment>
        <translation>Eksportuoti</translation>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation>VPN L2TP %1</translation>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation>VPN PPTP %1</translation>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation>VPN VPNC %1</translation>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation>VPN OpenVPN %1</translation>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation>VPN StrongSwan %1</translation>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation>VPN OpenConnect %1</translation>
    </message>
</context>
<context>
    <name>DCCNetworkModule</name>
    <message>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programos įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Asmeninis prieigos taškas</translation>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Išsamesnė tinklo informacija</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistemos įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Laidinis tinklas</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Laidinio tinklo adapteris</translation>
        <extra-contents_path>/network/Wired Network</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Pridėti tinklo ryšį</translation>
        <extra-contents_path>/network/Wired Network/addWiredConnection</extra-contents_path>
        <extra-child_page>Wired Network</extra-child_page>
    </message>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Belaidžio tinklo adapteris</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Prisijungti prie paslėpto tinklo</translation>
        <extra-contents_path>/network/Wireless Network/Connect to hidden network</extra-contents_path>
        <extra-child_page>Wireless Network</extra-child_page>
    </message>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
        <extra-contents_path>/network/DSL</extra-contents_path>
        <extra-child_page_hide>DSL</extra-child_page_hide>
    </message>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Sukurti PPPoE ryšį</translation>
        <extra-contents_path>/network/DSL/Create PPPoE Connection</extra-contents_path>
        <extra-child_page>DSL</extra-child_page>
    </message>
    <message>
        <source>VPN Status</source>
        <translation>VPN būsena</translation>
        <extra-contents_path>/network/VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Sukurti VPN</translation>
        <extra-contents_path>/network/VPN/Create VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importuoti VPN</translation>
        <extra-contents_path>/network/VPN/Import VPN</extra-contents_path>
        <extra-child_page>VPN</extra-child_page>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Įgaliotojo serverio tipas</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigūracijos URL</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresas</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Port</source>
        <translation>Prievadas</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
        <extra-contents_path>/network/Application Proxy</extra-contents_path>
        <extra-child_page>Application Proxy</extra-child_page>
    </message>
    <message>
        <source>Hotspot</source>
        <translation>Prieigos taškas</translation>
        <extra-contents_path>/network/Personal Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Create Hotspot</source>
        <translation>Sukurti prieigos tašką</translation>
        <extra-contents_path>/network/Personal Hotspot/Create Hotspot</extra-contents_path>
        <extra-child_page>Personal Hotspot</extra-child_page>
    </message>
    <message>
        <source>Interface</source>
        <translation>Sąsaja</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Band</source>
        <translation>Juosta</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Pirminis DNS</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tinklo kaukė</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Priešdelis</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
    <message>
        <source>Speed</source>
        <translation>Greitis</translation>
        <extra-contents_path>/network/Network Details</extra-contents_path>
        <extra-child_page>Network Details</extra-child_page>
    </message>
</context>
<context>
    <name>dccV20::network::AirplaneModepage</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabling the airplane mode turns off wireless network, personal hotspot and Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DNSSection</name>
    <message>
        <source>DNS</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid DNS address</source>
        <translation>Neteisingas DNS adresas</translation>
    </message>
</context>
<context>
    <name>EthernetSection</name>
    <message>
        <source>Ethernet</source>
        <translation>Laidinis tinklas</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nesusietas</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Įrenginio MAC adresas</translation>
    </message>
    <message>
        <source>Cloned MAC Addr</source>
        <translation>Klonuotas MAC adresas</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Tinkinti MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
<context>
    <name>GenericHotspotSection</name>
    <message>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
</context>
<context>
    <name>GenericSection</name>
    <message>
        <source>General</source>
        <translation>Bendra</translation>
    </message>
    <message>
        <source>The name already exists</source>
        <translation>Pavadinimas jau yra</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Pavadinimas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Auto Connect</source>
        <translation>Automatiškai prisijungti</translation>
    </message>
</context>
<context>
    <name>HotspotDeviceWidget</name>
    <message>
        <source>Hotspot</source>
        <translation>Prieigos taškas</translation>
    </message>
    <message>
        <source>Add Settings</source>
        <translation>Pridėti nustatymus</translation>
    </message>
</context>
<context>
    <name>HotspotPage</name>
    <message>
        <source>Create Hotspot</source>
        <translation>Sukurti prieigos tašką</translation>
    </message>
</context>
<context>
    <name>IPInputSection</name>
    <message>
        <source>IP Address</source>
        <translation>IP adresas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
</context>
<context>
    <name>IPV4InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neteisingas IP adresas</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Neteisinga tinklo kaukė</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tinklo kaukė</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
</context>
<context>
    <name>IPV6InputSection</name>
    <message>
        <source>Duplicate IP address</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neteisingas IP adresas</translation>
    </message>
    <message>
        <source>Only one gateway is allowed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Priešdelis</translation>
    </message>
</context>
<context>
    <name>IpvxSection</name>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatinis</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Rankinis</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Nepaisyti</translation>
    </message>
    <message>
        <source>IP Address</source>
        <translation>IP adresas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Only applied in corresponding resources</source>
        <translation>Taikoma tik atitinkamuose ištekliuose</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Metodas</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Tinklo kaukė</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Priešdelis</translation>
    </message>
    <message>
        <source>Invalid IP address</source>
        <translation>Neteisingas IP adresas</translation>
    </message>
    <message>
        <source>Invalid netmask</source>
        <translation>Neteisinga tinklo kaukė</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultiIpvxSection</name>
    <message>
        <source>Method</source>
        <translation>Metodas</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatinis</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Rankinis</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Nepaisyti</translation>
    </message>
</context>
<context>
    <name>NetworkDetailPage</name>
    <message>
        <source>Network Details</source>
        <translation>Išsamesnė tinklo informacija</translation>
    </message>
</context>
<context>
    <name>NetworkModuleWidget</name>
    <message>
        <source>DSL</source>
        <translation>DSL</translation>
    </message>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>System Proxy</source>
        <translation>Sistemos įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Application Proxy</source>
        <translation>Programos įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
        <extra-contents_path>/network/Airplane</extra-contents_path>
    </message>
    <message>
        <source>Network Details</source>
        <translation>Išsamesnė tinklo informacija</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Tinklas</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Rankinis</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatinis</translation>
    </message>
    <message>
        <source>Configure by Network Manager</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Personal Hotspot</source>
        <translation>Asmeninis prieigos taškas</translation>
    </message>
</context>
<context>
    <name>PPPOESection</name>
    <message>
        <source>PPPoE</source>
        <translation>PPPoE</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Service</source>
        <translation>Servisas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
</context>
<context>
    <name>PPPSection</name>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Atsisakyti EAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Atsisakyti PAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Atsisakyti CHAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Atsisakyti MSCHAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Atsisakyti MSCHAPv2 tapatybės nustatymo</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Be BSD duomenų glaudinimo</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Be nuostolingojo duomenų glaudinimo</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Be TCP antraštės glaudinimo</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Be protokolo lauko glaudinimo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Be adreso/valdymo glaudinimo</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Siųsti PPP aido paketus</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Naudoti MPPE</translation>
    </message>
    <message>
        <source>128-bit MPPE</source>
        <translation>128-bitų MPPE</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Įsimenamoji MPPE</translation>
    </message>
</context>
<context>
    <name>PppoePage</name>
    <message>
        <source>Create PPPoE Connection</source>
        <translation>Sukurti PPPoE ryšį</translation>
    </message>
    <message>
        <source>PPP</source>
        <translation>PPP</translation>
    </message>
</context>
<context>
    <name>ProxyPage</name>
    <message>
        <source>System Proxy</source>
        <translation>Sistemos įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Atsisakyti</translation>
    </message>
    <message>
        <source>Save</source>
        <comment>button</comment>
        <translation>Įrašyti</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Įgaliotojo serverio tipas</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
    <message>
        <source>Manual</source>
        <translation>Rankinis</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatinis</translation>
    </message>
    <message>
        <source>Optional</source>
        <translation>Nebūtina</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Prievadas</translation>
    </message>
    <message>
        <source>HTTP Proxy</source>
        <translation>HTTP įgaliotasis serveris</translation>
    </message>
    <message>
        <source>HTTPS Proxy</source>
        <translation>HTTPS įgaliotasis serveris</translation>
    </message>
    <message>
        <source>FTP Proxy</source>
        <translation>FTP įgaliotasis serveris</translation>
    </message>
    <message>
        <source>SOCKS Proxy</source>
        <translation>SOCKS įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Ignore the proxy configurations for the above hosts and domains</source>
        <translation>Nepaisyti įgaliotojo serverio konfigūracijų aukščiau esantiems serveriams ir sritims</translation>
    </message>
    <message>
        <source>Configuration URL</source>
        <translation>Konfigūracijos URL</translation>
        <extra-contents_path>/network/System Proxy</extra-contents_path>
        <extra-child_page>System Proxy</extra-child_page>
    </message>
</context>
<context>
    <name>Secret8021xSection</name>
    <message>
        <source>Security</source>
        <translation>Saugumas</translation>
    </message>
    <message>
        <source>TLS</source>
        <translation>TLS</translation>
    </message>
    <message>
        <source>MD5</source>
        <translation>MD5</translation>
    </message>
    <message>
        <source>LEAP</source>
        <translation>LEAP</translation>
    </message>
    <message>
        <source>FAST</source>
        <translation>FAST</translation>
    </message>
    <message>
        <source>Tunneled TLS</source>
        <translation>Tuneliuotas TLS</translation>
    </message>
    <message>
        <source>Protected EAP</source>
        <translation>Apsaugota EAP</translation>
    </message>
    <message>
        <source>Save password for this user</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save password for all users</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Ask me always</source>
        <translation>Visada klausti</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>Anonymous</source>
        <translation>Anonimas</translation>
    </message>
    <message>
        <source>Authenticated</source>
        <translation>Tapatybė nustatyta</translation>
    </message>
    <message>
        <source>Both</source>
        <translation>Abu</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatiškai</translation>
    </message>
    <message>
        <source>Version 0</source>
        <translation>Versija 0</translation>
    </message>
    <message>
        <source>Version 1</source>
        <translation>Versija 1</translation>
    </message>
    <message>
        <source>EAP Auth</source>
        <translation>EAP patvirtinimas</translation>
    </message>
    <message>
        <source>Identity</source>
        <translation>Tapatybė</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Slaptažodžio parametrai</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatusis raktas</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>LĮ liudijimas</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Naudotojo liudijimas</translation>
    </message>
    <message>
        <source>Anonymous ID</source>
        <translation>Anoniminis ID</translation>
    </message>
    <message>
        <source>Provisioning</source>
        <translation>Aprūpinimas</translation>
    </message>
    <message>
        <source>PAC file</source>
        <translation>PAC failas</translation>
    </message>
    <message>
        <source>Inner Auth</source>
        <translation>Vidinė autentifikacija</translation>
    </message>
    <message>
        <source>PEAP Version</source>
        <translation>PEAP versija</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privatusis slaptažodis</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
</context>
<context>
    <name>SecretHotspotSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neteisingas slaptažodis</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 asmeninis</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Saugumas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Raktas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
</context>
<context>
    <name>SecretWiredSection</name>
    <message>
        <source>Security Required</source>
        <translation>Privalomas saugumas</translation>
    </message>
</context>
<context>
    <name>SecretWirelessSection</name>
    <message>
        <source>Invalid password</source>
        <translation>Neteisingas slaptažodis</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>WEP</source>
        <translation>WEP</translation>
    </message>
    <message>
        <source>WPA/WPA2 Personal</source>
        <translation>WPA/WPA2 asmeninis</translation>
    </message>
    <message>
        <source>WPA/WPA2 Enterprise</source>
        <translation>WPA/WPA2 verslo</translation>
    </message>
    <message>
        <source>WPA3 Personal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shared key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open system</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security</source>
        <translation>Saugumas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key</source>
        <translation>Raktas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
</context>
<context>
    <name>VpnAdvOpenVPNSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN sudėtingiau</translation>
    </message>
    <message>
        <source>Customize Gateway Port</source>
        <translation>Tinkinti tinklų sietuvo prievadą</translation>
    </message>
    <message>
        <source>Gateway Port</source>
        <translation>Tinklų sietuvo prievadas</translation>
    </message>
    <message>
        <source>Customize Renegotiation Interval</source>
        <translation>Tinkinti pakartotinių derybų intervalą</translation>
    </message>
    <message>
        <source>Renegotiation Interval</source>
        <translation>Pakartotinių derybų intervalas</translation>
    </message>
    <message>
        <source>Use LZO Data Compression</source>
        <translation>Naudoti LZO duomenų glaudinimą</translation>
    </message>
    <message>
        <source>Use TCP Connection</source>
        <translation>Naudoti TCP ryšį</translation>
    </message>
    <message>
        <source>Use TAP Device</source>
        <translation>Naudoti TAP įrenginį</translation>
    </message>
    <message>
        <source>Customize Tunnel MTU</source>
        <translation>Tinkinti tunelio MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
    <message>
        <source>Customize UDP Fragment Size</source>
        <translation>Tinkinti UDP fragmento dydį</translation>
    </message>
    <message>
        <source>UDP Fragment Size</source>
        <translation>UDP fragmento dydis</translation>
    </message>
    <message>
        <source>Restrict Tunnel TCP MSS</source>
        <translation>Apriboti tunelio TCP MSS</translation>
    </message>
    <message>
        <source>Randomize Remote Hosts</source>
        <translation>Atsitiktinai išdėstyti nuotolinius serverius</translation>
    </message>
</context>
<context>
    <name>VpnAdvVPNCSection</name>
    <message>
        <source>VPN Advanced</source>
        <translation>VPN sudėtingiau</translation>
    </message>
    <message>
        <source>Cisco (default)</source>
        <translation>Cisco (pagal numatymą)</translation>
    </message>
    <message>
        <source>Netscreen</source>
        <translation>Netscreen</translation>
    </message>
    <message>
        <source>Secure (default)</source>
        <translation>Saugus (numatytas)</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Silpnas</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>NAT-T When Available (default)</source>
        <translation>NAT-T kai prieinama (pagal numatymą)</translation>
    </message>
    <message>
        <source>NAT-T Always</source>
        <translation>NAT-T visada</translation>
    </message>
    <message>
        <source>Cisco UDP</source>
        <translation>Cisco UDP</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>DH Group 1</source>
        <translation>DH grupė 1</translation>
    </message>
    <message>
        <source>DH Group 2 (default)</source>
        <translation>DH grupė 2 (numatytas)</translation>
    </message>
    <message>
        <source>DH Group 5</source>
        <translation>DH grupė 5</translation>
    </message>
    <message>
        <source>Server (default)</source>
        <translation>Serveris (numatytas)</translation>
    </message>
    <message>
        <source>DH Group 2</source>
        <translation>DH grupė 2</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Sritis</translation>
    </message>
    <message>
        <source>Vendor</source>
        <translation>Gamintojas</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versija</translation>
    </message>
    <message>
        <source>Encryption</source>
        <translation>Šifravimas</translation>
    </message>
    <message>
        <source>NAT Traversal Mode</source>
        <translation>NAT apėjimo veiksena</translation>
    </message>
    <message>
        <source>IKE DH Group</source>
        <translation>IKE DH grupė</translation>
    </message>
    <message>
        <source>Forward Secrecy</source>
        <translation>Pažangus slaptumas</translation>
    </message>
    <message>
        <source>Local Port</source>
        <translation>Vietinis prievadas</translation>
    </message>
    <message>
        <source>Disable Dead Peer Detection</source>
        <translation>Išjungti neveikiančių lygiarangių aptikimą</translation>
    </message>
</context>
<context>
    <name>VpnIpsecSection</name>
    <message>
        <source>VPN IPsec</source>
        <translation>VPN IPsec</translation>
    </message>
    <message>
        <source>Enable IPsec</source>
        <translation>Įjungti IPsec</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Grupės pavadinimas</translation>
    </message>
    <message>
        <source>Group ID</source>
        <translation>Grupės ID</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Iš anksto padalintas raktas</translation>
    </message>
    <message>
        <source>Phase1 Algorithms</source>
        <translation>Phase1 algoritmai</translation>
    </message>
    <message>
        <source>Phase2 Algorithms</source>
        <translation>Phase2 algoritmai</translation>
    </message>
</context>
<context>
    <name>VpnOpenConnectSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>LĮ liudijimas</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Allow Cisco Secure Desktop Trojan</source>
        <translation>Leisti Cisco saugų darbalaukio Trojos arklį</translation>
    </message>
    <message>
        <source>CSD Script</source>
        <translation>CSD scenarijus</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Naudotojo liudijimas</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatusis raktas</translation>
    </message>
    <message>
        <source>Use FSID for Key Passphrase</source>
        <translation>Naudoti FSID kaip raktinį kodą</translation>
    </message>
</context>
<context>
    <name>VpnOpenVPNSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Certificates (TLS)</source>
        <translation>Liudijimai (TLS)</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Certificates with Password (TLS)</source>
        <translation>Liudijimai su slaptažodžiu (TLS)</translation>
    </message>
    <message>
        <source>Static Key</source>
        <translation>Statinis raktas</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Įrašytas</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Klausti</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nebūtina</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Autentifikacijos tipas</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>LĮ liudijimas</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Naudotojo liudijimas</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatusis raktas</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Slaptažodžio parametrai</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Privatusis slaptažodis</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Tinkinti rakto kryptį</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Rakto kryptis</translation>
    </message>
    <message>
        <source>Remote IP</source>
        <translation>Nuotolinis IP</translation>
    </message>
    <message>
        <source>Local IP</source>
        <translation>Vietinis IP</translation>
    </message>
</context>
<context>
    <name>VpnPPPSection</name>
    <message>
        <source>VPN PPP</source>
        <translation>VPN PPP</translation>
    </message>
    <message>
        <source>All Available (default)</source>
        <translation>Leidžiami visi (numatytas)</translation>
    </message>
    <message>
        <source>40-bit (less secure)</source>
        <translation>40-bit (mažiau saugus)</translation>
    </message>
    <message>
        <source>128-bit (most secure)</source>
        <translation>128-bit (saugiausias)</translation>
    </message>
    <message>
        <source>Refuse EAP Authentication</source>
        <translation>Atsisakyti EAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse PAP Authentication</source>
        <translation>Atsisakyti PAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse CHAP Authentication</source>
        <translation>Atsisakyti CHAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse MSCHAP Authentication</source>
        <translation>Atsisakyti MSCHAP tapatybės nustatymo</translation>
    </message>
    <message>
        <source>Refuse MSCHAPv2 Authentication</source>
        <translation>Atsisakyti MSCHAPv2 tapatybės nustatymo</translation>
    </message>
    <message>
        <source>No BSD Data Compression</source>
        <translation>Be BSD duomenų glaudinimo</translation>
    </message>
    <message>
        <source>No Deflate Data Compression</source>
        <translation>Be nuostolingojo duomenų glaudinimo</translation>
    </message>
    <message>
        <source>No TCP Header Compression</source>
        <translation>Be TCP antraštės glaudinimo</translation>
    </message>
    <message>
        <source>No Protocol Field Compression</source>
        <translation>Be protokolo lauko glaudinimo</translation>
    </message>
    <message>
        <source>No Address/Control Compression</source>
        <translation>Be adreso/valdymo glaudinimo</translation>
    </message>
    <message>
        <source>Send PPP Echo Packets</source>
        <translation>Siųsti PPP aido paketus</translation>
    </message>
    <message>
        <source>Use MPPE</source>
        <translation>Naudoti MPPE</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Saugumas</translation>
    </message>
    <message>
        <source>Stateful MPPE</source>
        <translation>Įsimenamoji MPPE</translation>
    </message>
</context>
<context>
    <name>VpnPage</name>
    <message>
        <source>VPN Status</source>
        <translation>VPN būsena</translation>
    </message>
    <message>
        <source>Create VPN</source>
        <translation>Sukurti VPN</translation>
    </message>
    <message>
        <source>Import VPN</source>
        <translation>Importuoti VPN</translation>
    </message>
    <message>
        <source>Import Error</source>
        <translation>Importavimo klaida</translation>
    </message>
    <message>
        <source>File error</source>
        <translation>Failo klaida</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Gerai</translation>
    </message>
</context>
<context>
    <name>VpnProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nebūtina</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>SOCKS</source>
        <translation>SOCKS</translation>
    </message>
    <message>
        <source>Proxy Type</source>
        <translation>Įgaliotojo serverio tipas</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Serverio IP</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Prievadas</translation>
    </message>
    <message>
        <source>Retry Indefinitely When Failed</source>
        <translation>Nepavykus, be perstojo bandyti vėl</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
</context>
<context>
    <name>VpnSSTPSection</name>
    <message>
        <source>CA File</source>
        <translation>LĮ failas</translation>
    </message>
    <message>
        <source>Ignore Certificate Warnings</source>
        <translation>Nepaisyti liudijimų įspėjimų</translation>
    </message>
    <message>
        <source>Use TLS Hostname Extensions</source>
        <translation>Naudoti TLS kompiuterių vardų plėtinius</translation>
    </message>
</context>
<context>
    <name>VpnSecOpenVPNSection</name>
    <message>
        <source>VPN Security</source>
        <translation>VPN saugumas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Numatytasis</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nėra</translation>
    </message>
    <message>
        <source>Cipher</source>
        <translation>Šifras</translation>
    </message>
    <message>
        <source>HMAC Auth</source>
        <translation>HMAC autentifikacija</translation>
    </message>
</context>
<context>
    <name>VpnSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Įrašytas</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Klausti</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nebūtina</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Slaptažodžio parametrai</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>NT Domain</source>
        <translation>NT sritis</translation>
    </message>
</context>
<context>
    <name>VpnSstpProxySection</name>
    <message>
        <source>VPN Proxy</source>
        <translation>VPN įgaliotasis serveris</translation>
    </message>
    <message>
        <source>Server IP</source>
        <translation>Serverio IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Prievadas</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
</context>
<context>
    <name>VpnStrongSwanSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Private Key</source>
        <translation>Privatusis raktas</translation>
    </message>
    <message>
        <source>SSH Agent</source>
        <translation>SSH agentas</translation>
    </message>
    <message>
        <source>Smart Card</source>
        <translation>Lustinė kortelė</translation>
    </message>
    <message>
        <source>EAP</source>
        <translation>EAP</translation>
    </message>
    <message>
        <source>Pre-Shared Key</source>
        <translation>Iš anksto padalintas raktas</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>CA Cert</source>
        <translation>LĮ liudijimas</translation>
    </message>
    <message>
        <source>Auth Type</source>
        <translation>Autentifikacijos tipas</translation>
    </message>
    <message>
        <source>User Cert</source>
        <translation>Naudotojo liudijimas</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Request an Inner IP Address</source>
        <translation>Užklausti vidinį IP adresą</translation>
    </message>
    <message>
        <source>Enforce UDP Encapsulation</source>
        <translation>Versti vykdyti UDP sandarinimą</translation>
    </message>
    <message>
        <source>Use IP Compression</source>
        <translation>Naudoti IP glaudinimą</translation>
    </message>
    <message>
        <source>Enable Custom Cipher Proposals</source>
        <translation>Įjungti tinkintus šifro pasiūlymus</translation>
    </message>
    <message>
        <source>IKE</source>
        <translation>IKE</translation>
    </message>
    <message>
        <source>ESP</source>
        <translation>ESP</translation>
    </message>
</context>
<context>
    <name>VpnTLSSection</name>
    <message>
        <source>VPN TLS Authentication</source>
        <translation>VPN TLS tapatybės nustatymas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Numatytasis</translation>
    </message>
    <message>
        <source>Client</source>
        <translation>Klientas</translation>
    </message>
    <message>
        <source>Server</source>
        <translation>Serveris</translation>
    </message>
    <message>
        <source>Subject Match</source>
        <translation>Temos atitikimas</translation>
    </message>
    <message>
        <source>Remote Cert Type</source>
        <translation>Nuotolinio certifikato tipas</translation>
    </message>
    <message>
        <source>Key File</source>
        <translation>Rakto failas</translation>
    </message>
    <message>
        <source>Customize Key Direction</source>
        <translation>Tinkinti rakto kryptį</translation>
    </message>
    <message>
        <source>Key Direction</source>
        <translation>Rakto kryptis</translation>
    </message>
</context>
<context>
    <name>VpnVPNCSection</name>
    <message>
        <source>VPN</source>
        <translation>VPN</translation>
    </message>
    <message>
        <source>Invalid gateway</source>
        <translation>Neteisingas tinklų sietuvas</translation>
    </message>
    <message>
        <source>Saved</source>
        <translation>Įrašytas</translation>
    </message>
    <message>
        <source>Ask</source>
        <translation>Klausti</translation>
    </message>
    <message>
        <source>Not Required</source>
        <translation>Nebūtina</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Tinklų sietuvas</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Naudotojo vardas</translation>
    </message>
    <message>
        <source>Pwd Options</source>
        <translation>Slaptažodžio parametrai</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Slaptažodis</translation>
    </message>
    <message>
        <source>Group Name</source>
        <translation>Grupės pavadinimas</translation>
    </message>
    <message>
        <source>Group Pwd</source>
        <translation>Grupės slaptažodis</translation>
    </message>
    <message>
        <source>Use Hybrid Authentication</source>
        <translation>Naudoti hibridinį tapatybės nustatymą</translation>
    </message>
    <message>
        <source>CA File</source>
        <translation>LĮ failas</translation>
    </message>
</context>
<context>
    <name>WiredPage</name>
    <message>
        <source>Plug in the network cable first</source>
        <translation>Iš pradžių, prijunkite tinklo laidą</translation>
    </message>
    <message>
        <source>Wired Network Adapter</source>
        <translation>Laidinio tinklo adapteris</translation>
    </message>
    <message>
        <source>Add Network Connection</source>
        <translation>Pridėti tinklo ryšį</translation>
    </message>
    <message>
        <source>Select Settings</source>
        <translation>Pasirinkti nustatymus</translation>
    </message>
</context>
<context>
    <name>WirelessPage</name>
    <message>
        <source>Wireless Network Adapter</source>
        <translation>Belaidžio tinklo adapteris</translation>
        <extra-contents_path>/network/Wireless Network</extra-contents_path>
    </message>
    <message>
        <source>Close Hotspot</source>
        <translation>Uždaryti prieigos tašką</translation>
    </message>
    <message>
        <source>Disable hotspot first if you want to connect to a wireless network</source>
        <translation>Norėdami prisijungti prie belaidžio tinklo, iš pradžių, išjunkite prieigos tašką</translation>
    </message>
    <message>
        <source>Connect to hidden network</source>
        <translation>Prisijungti prie paslėpto tinklo</translation>
        <extra-contents_path>/network/Connect to hidden network</extra-contents_path>
        <extra-child_page>WirelessPage</extra-child_page>
    </message>
</context>
<context>
    <name>WirelessSection</name>
    <message>
        <source>WLAN</source>
        <translation>Belaidis tinklas</translation>
    </message>
    <message>
        <source>Not Bind</source>
        <translation>Nesusietas</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Required</source>
        <translation>Būtina</translation>
    </message>
    <message>
        <source>Device MAC Addr</source>
        <translation>Įrenginio MAC adresas</translation>
    </message>
    <message>
        <source>Customize MTU</source>
        <translation>Tinkinti MTU</translation>
    </message>
    <message>
        <source>MTU</source>
        <translation>MTU</translation>
    </message>
</context>
</TS>